@@ -20,15 +20,15 @@ use Types::TypeTiny qw(HashLike);
 use Types::Path::Tiny qw(Dir File Path);
 use Boxer::Types qw(SkelDir Basename);
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.6
+Version v1.1.8
 
 =cut
 
-our $VERSION = version->declare("v1.1.6");
+our $VERSION = version->declare("v1.1.8");
 
 # permit callers to sloppily pass undefined values
 sub BUILDARGS
