@@ -17,15 +17,15 @@ use autodie;
 
 use Moo;
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.6
+Version v1.1.8
 
 =cut
 
-our $VERSION = version->declare("v1.1.6");
+our $VERSION = version->declare("v1.1.8");
 
 =head1 DESCRIPTION
 
