@@ -23,15 +23,15 @@ use Types::Standard qw( Maybe Str Undef );
 use Boxer::Types qw( DataDir ClassDir NodeDir Suite );
 extends 'Boxer::Task';
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.6
+Version v1.1.8
 
 =cut
 
-our $VERSION = version->declare("v1.1.6");
+our $VERSION = version->declare("v1.1.8");
 
 # permit callers to sloppily pass undefined values
 sub BUILDARGS
