@@ -16,20 +16,20 @@ use File::ShareDir qw(dist_dir);
 use Boxer::File::WithSkeleton;
 
 use Moo;
-use Types::Standard qw( Bool Str Undef InstanceOf );
+use Types::Standard qw( Bool Maybe Str Undef InstanceOf );
 use Types::Path::Tiny qw( Dir File Path );
 use Boxer::Types qw( SkelDir );
 extends 'Boxer::Task';
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.6
+Version v1.1.8
 
 =cut
 
-our $VERSION = version->declare("v1.1.6");
+our $VERSION = version->declare("v1.1.8");
 
 has world => (
 	is       => 'ro',
@@ -39,7 +39,7 @@ has world => (
 
 has skeldir => (
 	is     => 'ro',
-	isa    => SkelDir,
+	isa    => Maybe [SkelDir],
 	coerce => 1,
 );
 
