@@ -24,15 +24,15 @@ use Types::Standard qw(ArrayRef InstanceOf);
 use Boxer::World::Flat;
 with qw(MooX::Role::Logger);
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.6
+Version v1.1.8
 
 =cut
 
-our $VERSION = version->declare("v1.1.6");
+our $VERSION = version->declare("v1.1.8");
 
 =head1 DESCRIPTION
 
@@ -150,7 +150,7 @@ sub flatten
 		return ();
 	};
 	if ($nonfree) {
-		push @pkg, @{ $node->{'pkg-nonfree'} if ( $node->{'pkg-nonfree'} ) };
+		push @pkg, @{ $node->{'pkg-nonfree'} } if ( $node->{'pkg-nonfree'} );
 		push @pkgauto, @{ $node->{'pkg-nonfree-auto'} }
 			if ( $node->{'pkg-nonfree-auto'} );
 	}
